@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # * Authors:
 #       * Arezki Feth <f.a@majerti.fr>;
 #       * Miotte Julien <j.m@majerti.fr>;
@@ -16,6 +15,7 @@ from sqla_inspect.base import (
     BaseSqlaInspector,
     FormatterRegistry,
 )
+
 BLACKLISTED_KEYS = []
 
 
@@ -26,17 +26,18 @@ FORMATTERS_REGISTRY = FormatterRegistry()
 logger = logging.getLogger(__name__)
 
 
-class BaseExporter():
+class BaseExporter:
     """
     A base exportation object, used to export tabular datas (csv or xls format)
     Should be used in conjunction with a writer
     """
+
     headers = []
 
     def __init__(self, **kw):
         self._datas = []
         if "headers" in kw:
-            self.set_headers(kw['headers'])
+            self.set_headers(kw["headers"])
         self.extra_headers = []
 
     def set_headers(self, headers):
@@ -51,7 +52,7 @@ class BaseExporter():
 
     def add_row(self, row):
         """
-            Add a row to our buffer
+        Add a row to our buffer
         """
         self._datas.append(self.format_row(row))
 
@@ -94,13 +95,16 @@ def format_value(column_dict, value, key=None):
     :param value: A value coming from the database
     :param key: The exportation key
     """
-    formatter = column_dict.get('formatter')
-    prop = column_dict['__col__']
+    formatter = column_dict.get("formatter")
+    prop = column_dict["__col__"]
 
     res = value
 
-    if value in ('', None,):
-        res = ''
+    if value in (
+        "",
+        None,
+    ):
+        res = ""
 
     elif formatter is not None:
         res = formatter(value)
@@ -108,7 +112,7 @@ def format_value(column_dict, value, key=None):
     else:
         if hasattr(prop, "columns"):
             sqla_column = prop.columns[0]
-            column_type = getattr(sqla_column.type, 'impl', sqla_column.type)
+            column_type = getattr(sqla_column.type, "impl", sqla_column.type)
 
             formatter = FORMATTERS_REGISTRY.get_formatter(column_type, key)
             if formatter is not None:
@@ -140,7 +144,8 @@ class SqlaExporter(BaseExporter, BaseSqlaInspector):
             By default, we look for the title in the colanderalchemy's title
             key info={'colanderalchemy': {'title': u'Column title'}}
     """
-    config_key = ''
+
+    config_key = ""
 
     def __init__(self, model, **kw):
         BaseExporter.__init__(self)
@@ -154,7 +159,7 @@ class SqlaExporter(BaseExporter, BaseSqlaInspector):
         if prop.key in BLACKLISTED_KEYS:
             return True
 
-        if info_dict.get('exclude', False):
+        if info_dict.get("exclude", False):
             return True
 
         if prop.key in self.excludes:
@@ -169,9 +174,9 @@ class SqlaExporter(BaseExporter, BaseSqlaInspector):
         """
         Return the title configured as in colanderalchemy
         """
-        result = main_infos.get('label')
+        result = main_infos.get("label")
         if result is None:
-            result = info_dict.get('colanderalchemy', {}).get('title')
+            result = info_dict.get("colanderalchemy", {}).get("title")
         if result is None:
             result = prop.key
         return result
@@ -182,13 +187,13 @@ class SqlaExporter(BaseExporter, BaseSqlaInspector):
         different configuration level
         """
         info_dict = self.get_info_field(prop)
-        main_infos = info_dict.get('export', {}).copy()
+        main_infos = info_dict.get("export", {}).copy()
         infos = main_infos.get(self.config_key, {})
-        main_infos['label'] = self._get_title(prop, main_infos, info_dict)
-        main_infos['name'] = prop.key
-        main_infos['key'] = prop.key
+        main_infos["label"] = self._get_title(prop, main_infos, info_dict)
+        main_infos["name"] = prop.key
+        main_infos["key"] = prop.key
         main_infos.update(infos)
-        main_infos['__col__'] = prop
+        main_infos["__col__"] = prop
         return main_infos
 
     def _collect_headers(self):
@@ -209,8 +214,10 @@ class SqlaExporter(BaseExporter, BaseSqlaInspector):
 
                 if not main_infos:
                     # If still no success, we forgot this one
-                    print("Maybe there's missing some informations \
-about a relationship")
+                    print(
+                        "Maybe there's missing some informations \
+about a relationship"
+                    )
                     continue
             else:
                 main_infos = self._merge_many_to_one_field_from_fkey(
@@ -262,7 +269,7 @@ about a relationship")
             # One to many
             pass
         else:
-            if "related_key" in main_infos or 'formatter' in main_infos:
+            if "related_key" in main_infos or "formatter" in main_infos:
                 self._merge_many_to_one_field(main_infos, prop, result)
             else:
                 related_field_inspector = BaseSqlaInspector(prop.mapper)
@@ -273,13 +280,11 @@ about a relationship")
                     if self._is_excluded(column, infos):
                         continue
 
-                    infos['label'] = u"%s %s" % (
-                        main_infos['label'], infos['label']
-                    )
-                    infos['__col__'] = main_infos['__col__']
-                    infos['name'] = "%s %s" % (main_infos['name'], column.key)
-                    infos['key'] = main_infos['key']
-                    infos['related_key'] = column.key
+                    infos["label"] = u"%s %s" % (main_infos["label"], infos["label"])
+                    infos["__col__"] = main_infos["__col__"]
+                    infos["name"] = "%s %s" % (main_infos["name"], column.key)
+                    infos["key"] = main_infos["key"]
+                    infos["related_key"] = column.key
                     main_infos_list.append(infos)
                 return main_infos_list
 
@@ -300,11 +305,11 @@ about a relationship")
         # We first find the related foreignkey to get the good title
         rel_base = list(prop.local_columns)[0]
         related_fkey_name = rel_base.name
-        if not main_infos.get('keep_key', False):
+        if not main_infos.get("keep_key", False):
             for val in result:
-                if val['name'] == related_fkey_name:
-                    title = val['label']
-                    main_infos['label'] = title
+                if val["name"] == related_fkey_name:
+                    title = val["label"]
+                    main_infos["label"] = title
                     result.remove(val)
                     break
 
@@ -319,13 +324,13 @@ about a relationship")
         :param list result: The actual collected headers
         :returns: a main_infos dict or None
         """
-        if prop.columns[0].foreign_keys and prop.key.endswith('_id'):
+        if prop.columns[0].foreign_keys and prop.key.endswith("_id"):
             # We have a foreign key, we'll try to merge it with the
             # associated foreign key
             rel_name = prop.key[0:-3]
             for val in result:
                 if val["name"] == rel_name:
-                    val["label"] = main_infos['label']
+                    val["label"] = main_infos["label"]
                     main_infos = None  # We can forget this field in export
                     break
         return main_infos
@@ -341,16 +346,16 @@ about a relationship")
         row = {}
         for column in self.headers:
 
-            value = ''
+            value = ""
 
-            if '__col__' in column:
-                if isinstance(column['__col__'], ColumnProperty):
+            if "__col__" in column:
+                if isinstance(column["__col__"], ColumnProperty):
                     value = self._get_column_cell_val(obj, column)
 
-                elif isinstance(column['__col__'], RelationshipProperty):
+                elif isinstance(column["__col__"], RelationshipProperty):
                     value = self._get_relationship_cell_val(obj, column)
 
-            row[column['name']] = value
+            row[column["name"]] = value
 
         self._datas.append(self.format_row(row))
 
@@ -358,7 +363,7 @@ about a relationship")
         """
         Format the value of the attribute 'name' from the given object
         """
-        attr_path = name.split('.')
+        attr_path = name.split(".")
         val = None
         tmp_val = obj
         for attr in attr_path:
@@ -375,21 +380,21 @@ about a relationship")
         Return the value to insert in a relationship cell
         """
         val = ""
-        key = column['key']
-        related_key = column.get('related_key', None)
+        key = column["key"]
+        related_key = column.get("related_key", None)
 
         related_obj = getattr(obj, key, None)
 
         if related_obj is None:
             return ""
 
-        if column['__col__'].uselist:  # OneToMany
+        if column["__col__"].uselist:  # OneToMany
             # We know how to retrieve a value from the related objects
             if related_key is not None:
                 # Only the related object of the given index
-                if column.get('index') is not None:
-                    if len(related_obj) > column['index']:
-                        rel_obj = related_obj[column['index']]
+                if column.get("index") is not None:
+                    if len(related_obj) > column["index"]:
+                        rel_obj = related_obj[column["index"]]
                         val = self._get_formatted_val(
                             rel_obj,
                             related_key,
@@ -406,11 +411,11 @@ about a relationship")
                                 column,
                             )
                         )
-                    val = '\n'.join(_vals)
+                    val = "\n".join(_vals)
         else:  # Many to One
             if related_key is not None:
                 val = self._get_formatted_val(related_obj, related_key, column)
-            elif 'formatter' in column:
+            elif "formatter" in column:
                 val = format_value(column, related_obj)
 
         return val
@@ -419,5 +424,5 @@ about a relationship")
         """
         Return a value of a "column" cell
         """
-        name = column['name']
+        name = column["name"]
         return self._get_formatted_val(obj, name, column)
