@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # * Authors:
 #       * Arezki Feth <f.a@majerti.fr>;
 #       * Miotte Julien <j.m@majerti.fr>;
@@ -6,16 +5,20 @@
 
 from sqla_inspect import ascii
 
+
 def test_force_unicode():
     assert ascii.force_unicode("éko") == "éko"
-    assert ascii.force_unicode("éko".encode('utf-8')) == u"éko"
+    assert ascii.force_unicode("éko".encode("utf-8")) == u"éko"
+
 
 def test_force_utf8():
-    assert ascii.force_utf8("éko") == "éko".encode('utf-8')
+    assert ascii.force_utf8("éko") == "éko".encode("utf-8")
+
 
 def test_force_ascii():
     assert ascii.force_ascii("éko") == "eko"
-    assert ascii.force_ascii("éko".encode('utf-8')) == "eko"
+    assert ascii.force_ascii("éko".encode("utf-8")) == "eko"
+
 
 def test_camel_case_to_name():
     assert ascii.camel_case_to_name("BaseObject") == "base_object"
